camelot.camelot.view.controls.editors.RichTextEditor

Package camelot :: Package camelot :: Package view :: Package controls :: Module editors :: Class RichTextEditor |
[hide private]
[frames] | no frames]

# Class RichTextEditor

source code

Instance Methods | [hide private]
__init__(self, parent=None, editable=True, **kwargs) | source code
editingFinished(self) | source code
set_bold(self) | source code
set_italic(self, bool) | source code
set_underline(self, bool) | source code
set_alignleft(self, bool) | source code
set_aligncenter(self, bool) | source code
set_alignright(self, bool) | source code
update_alignment(self, al=None) | source code
set_color(self) | source code
update_color(self) | source code
update_format(self, format) | source code
update_text(self) | source code
clear(self) | source code
setHtml(self, html) | source code
toHtml(self) | source code